@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING
 
 import kfactory as kf
 
-from gdsfactory.component import Component, boolean_operations
+from gdsfactory.component import Component, ComponentReference, boolean_operations
 
 if TYPE_CHECKING:
     from gdsfactory.typings import ComponentOrReference, LayerSpec
@@ -14,34 +14,30 @@ def boolean(
     A: ComponentOrReference,
     B: ComponentOrReference,
     operation: str,
+    layer: LayerSpec,
     layer1: LayerSpec | None = None,
     layer2: LayerSpec | None = None,
-    layer: LayerSpec = (1, 0),
 ) -> Component:
-    """Performs boolean operations between 2 Component/Reference/list objects.
+    """Performs boolean operations between 2 Component or Instance objects.
 
-    ``operation`` should be one of {'not', 'and', 'or', 'xor', '-', '&', '|', '^'}.
-    Note that '|' is equivalent to 'or', '-' is equivalent to 'not',
-    '&' is equivalent to 'and', and '^' is equivalent to 'xor'.
+    The `operation` parameter specifies the type of boolean operation to perform.
+    Supported operations include {'not', 'and', 'or', 'xor', '-', '&', '|', '^'}:
+      - `'|'` is equivalent to `'or'`
+      - `'-'` is equivalent to `'not'`
+      - `'&'` is equivalent to `'and'`
+      - `'^'` is equivalent to `'xor'`
 
     Args:
         A: Component(/Reference) or list of Component(/References).
         B: Component(/Reference) or list of Component(/References).
         operation: {'not', 'and', 'or', 'xor', '-', '&', '|', '^'}.
+        layer: Specific layer to put polygon geometry on.
         layer1: Specific layer to get polygons.
         layer2: Specific layer to get polygons.
-        layer: Specific layer to put polygon geometry on.
 
     Returns: Component with polygon(s) of the boolean operations between
       the 2 input Components performed.
 
-    Notes:
-    -----
-    - '|' is equivalent to 'or'.
-    - '-' is equivalent to 'not'.
-    - '&' is equivalent to 'and'.
-    - '^' is equivalent to 'not'.
-
     .. plot::
       :include-source:
 
@@ -50,7 +46,7 @@ def boolean(
       c = gf.Component()
       c1 = c << gf.components.circle(radius=10)
       c2 = c << gf.components.circle(radius=9)
-      c2.dmovex(5)
+      c2.movex(5)
 
       c = gf.boolean(c1, c2, operation="xor")
       c.plot()
@@ -71,35 +67,50 @@ def boolean(
     layer_index2 = get_layer(layer2)
     layer_index = get_layer(layer)
 
-    if isinstance(A, kf.KCell):
+    if isinstance(A, kf.DKCell):
         ar = kf.kdb.Region(A.begin_shapes_rec(layer_index1))
     else:
-        ar = kf.kdb.Region(A.cell.begin_shapes_rec(layer_index1)).transformed(
-            A.cplx_trans
-        )
-    if isinstance(B, kf.KCell):
+        ar = get_ref_shapes(A, layer_index1)
+    if isinstance(B, kf.DKCell):
         br = kf.kdb.Region(B.begin_shapes_rec(layer_index2))
     else:
-        br = kf.kdb.Region(B.cell.begin_shapes_rec(layer_index2)).transformed(
-            B.cplx_trans
-        )
-
+        br = get_ref_shapes(B, layer_index2)
     c.shapes(layer_index).insert(boolean_operations[operation](ar, br))
 
     return c
 
 
+def get_ref_shapes(ref: ComponentReference, layer_index: int) -> kf.kdb.Region:
+    if ref.is_regular_array():
+        base_inst_region = kf.kdb.Region(ref.cell.begin_shapes_rec(layer_index))
+
+        br = kf.kdb.Region()
+        for ia in range(ref.na):
+            for ib in range(ref.nb):
+                br.insert(
+                    base_inst_region.transformed(
+                        ref.cplx_trans * kf.kdb.ICplxTrans(ia * ref.a + ib * ref.b)
+                    )
+                )
+    else:
+        br = kf.kdb.Region(ref.cell.begin_shapes_rec(layer_index)).transformed(
+            ref.cplx_trans
+        )
+    return br
+
+
 if __name__ == "__main__":
     import gdsfactory as gf
+    from gdsfactory.components import bbox, coupler
 
     # c = gf.Component()
     # e2 = c << gf.components.ellipse(radii=(10, 6))
     # e3 = c << gf.components.ellipse(radii=(10, 4))
-    # e3.dmovex(5)
+    # e3.movex(5)
     # c = boolean(A=e2, B=e3, operation="and")
     c0 = gf.Component()
-    core = c0 << gf.c.coupler()
-    clad = c0 << gf.c.bbox(core, layer=(2, 0))
-    clad.dmovex(5)
+    core = c0 << coupler()
+    clad = c0 << bbox(core, layer=(2, 0))
+    clad.movex(5)
     c = boolean(clad, core, operation="not", layer=(3, 0), layer1=(2, 0), layer2=(1, 0))
     c.show()
