@@ -193,6 +193,18 @@ from gdsfactory.components.pcms import (
     version_stamp,
     widths,
 )
+from gdsfactory.components.quantum import (
+    coupler_capacitive,
+    coupler_interdigital,
+    coupler_tunable,
+    flux_qubit,
+    flux_qubit_asymmetric,
+    resonator_cpw,
+    resonator_lumped,
+    resonator_quarter_wave,
+    transmon,
+    transmon_circular,
+)
 from gdsfactory.components.rings import (
     coupler_bend,
     coupler_ring_bend,
@@ -403,12 +415,15 @@ __all__ = [
     "coupler_bend",
     "coupler_bent",
     "coupler_broadband",
+    "coupler_capacitive",
     "coupler_full",
+    "coupler_interdigital",
     "coupler_ring",
     "coupler_ring_bend",
     "coupler_straight",
     "coupler_straight_asymmetric",
     "coupler_symmetric",
+    "coupler_tunable",
     "couplers",
     "cross",
     "crossing",
@@ -453,6 +468,8 @@ __all__ = [
     "fiber_size",
     "fiducial_squares",
     "filters",
+    "flux_qubit",
+    "flux_qubit_asymmetric",
     "free_propagation_region",
     "ge_detector_straight_si_contacts",
     "generate_doe",
@@ -545,6 +562,9 @@ __all__ = [
     "regular_polygon",
     "resistance_meander",
     "resistance_sheet",
+    "resonator_cpw",
+    "resonator_lumped",
+    "resonator_quarter_wave",
     "ring",
     "ring_asymmetric",
     "ring_crow",
@@ -628,6 +648,8 @@ __all__ = [
     "text_rectangular_font",
     "text_rectangular_multi_layer",
     "texts",
+    "transmon",
+    "transmon_circular",
     "triangle",
     "triangle2",
     "triangle2_thin",
