@@ -1,7 +1,6 @@
 from gdsfactory.labels.add_label_yaml import add_label_json, add_label_yaml
 from gdsfactory.labels.add_labels import add_port_labels
 from gdsfactory.labels.ehva import add_label_ehva, ignore, prefix_to_type_default
-from gdsfactory.labels.get_test_manifest import get_test_manifest
 from gdsfactory.labels.write_labels import find_labels, write_labels
 from gdsfactory.labels.write_test_manifest import write_test_manifest
 
@@ -11,7 +10,6 @@ __all__ = [
     "add_label_yaml",
     "add_port_labels",
     "find_labels",
-    "get_test_manifest",
     "ignore",
     "prefix_to_type_default",
     "write_labels",
