@@ -1,3 +1,5 @@
+from collections.abc import Sequence
+
 import gdsfactory as gf
 from gdsfactory.typings import LayerSpec, Ports
 
@@ -6,7 +8,7 @@ def add_port_labels(
     component: gf.Component,
     ports: Ports,
     layer: LayerSpec,
-    texts: list[str] | None = None,
+    texts: Sequence[str] | None = None,
 ) -> gf.Component:
     """Add port labels to a component.
 
@@ -16,12 +18,12 @@ def add_port_labels(
         layer: layer to add the labels.
         texts: text to add to the labels. Defaults to port names.
     """
-    texts = texts or [port.name for port in ports]
+    texts = texts or [port.name for port in ports if port.name is not None]
 
     for text, port in zip(texts, ports):
         component.add_label(
             text=text,
-            position=port.dcenter,
+            position=port.center,
             layer=layer,
         )
     return component
@@ -29,10 +31,12 @@ def add_port_labels(
 
 if __name__ == "__main__":
     c = gf.Component()
+    from gdsfactory.components import wire_straight
+
     # ref = c << gf.components.straight()
     # ref = c << gf.routing.add_fiber_array(gf.components.straight())
     # ref = c << gf.routing.add_fiber_array(gf.components.nxn())
-    ref = c << gf.routing.add_pads_top(gf.components.wire_straight())
+    ref = c << gf.routing.add_pads_top(wire_straight())
     # c = add_port_labels(c, [ref.ports["o1"]], layer=(2, 0))
     # c = add_port_labels(c, ref.ports, layer=(2, 0))
     # c = label_farthest_right_port(c, ref.ports, layer=(2, 0), text="output")
