@@ -164,7 +164,7 @@ class Pdk(BaseModel):
     )
     layers: type[LayerEnum] | None = None
     layer_stack: LayerStack | None = None
-    layer_views: LayerViews | None = None
+    layer_views: LayerViews | PathType | None = None
     layer_transitions: LayerTransitions = Field(default_factory=dict)
     constants: dict[str, Any] = constants
     materials_index: dict[str, MaterialSpec] = Field(default_factory=dict)
@@ -178,6 +178,24 @@ class Pdk(BaseModel):
         extra="forbid",
     )
 
+    def model_post_init(self, context: Any) -> None:
+        super().model_post_init(context)
+
+        # update the cross sections and cells from base pdks
+        # precedence goes from first to last base PDK, and then finally to this PDK
+        # (duplicates in the last base PDK will overwrite the others, and this PDK will overwrite that)
+        cross_sections = {}
+        cells = {}
+        for pdk in self.base_pdks:
+            cross_sections.update(pdk.cross_sections)
+            cells.update(pdk.cells)
+
+        cross_sections.update(self.cross_sections)
+        cells.update(self.cells)
+
+        self.cross_sections = cross_sections
+        self.cells = cells
+
     def xsection(
         self, func: Callable[..., CrossSection]
     ) -> Callable[..., CrossSection]:
@@ -209,14 +227,6 @@ class Pdk(BaseModel):
 
         logger.debug(f"{self.name!r} PDK {self.version} is now active")
 
-        for pdk in self.base_pdks:
-            cross_sections = pdk.cross_sections
-            cross_sections.update(self.cross_sections)
-            cells = pdk.cells
-            self.cross_sections = cross_sections
-            cells.update(self.cells)
-            self.cells.update(cells)
-
         _set_active_pdk(self)
 
     def register_cells(self, **kwargs: Any) -> None:
@@ -503,8 +513,9 @@ class Pdk(BaseModel):
         elif isinstance(layer, kf.kdb.LayerInfo):
             return layer.layer
         else:
-            if not hasattr(self.layers, layer):
-                raise ValueError(f"{layer!r} not in {self.layers}")
+            if self.layers is None or not hasattr(self.layers, layer):
+                layer_members = self.layers.__members__ if self.layers else {}
+                raise ValueError(f"{layer!r} not in PDK {self.name!r} {layer_members}")
             return cast(LayerEnum, getattr(self.layers, layer))
 
     def get_layer_name(self, layer: LayerSpec) -> str:
@@ -518,7 +529,7 @@ class Pdk(BaseModel):
             except Exception:
                 raise ValueError(f"Could not find name for layer {layer_index}")
 
-    def get_layer_views(self) -> LayerViews:
+    def get_layer_views(self) -> LayerViews | str | PathType:
         if self.layer_views is None:
             raise ValueError(f"layer_views for Pdk {self.name!r} is None")
         return self.layer_views
@@ -616,9 +627,17 @@ class Pdk(BaseModel):
             UserWarning if required properties for generating a KLayoutTechnology are not defined.
         """
         try:
+            # Convert layer_views path to LayerViews object if needed
+            layer_views_obj = None
+            if self.layer_views is not None:
+                if isinstance(self.layer_views, LayerViews):
+                    layer_views_obj = self.layer_views
+                else:
+                    layer_views_obj = LayerViews(filepath=self.layer_views)
+
             return klayout_tech.KLayoutTechnology(
                 name=self.name,
-                layer_views=self.layer_views,
+                layer_views=layer_views_obj,
                 connectivity=self.connectivity,
                 layer_map=self.layers,  # type: ignore[arg-type]
                 layer_stack=self.layer_stack,
@@ -698,7 +717,13 @@ def get_layer_tuple(layer: LayerSpec) -> tuple[int, int]:
     return info.layer, info.datatype
 
 
-def get_layer_views() -> LayerViews:
+def get_layer_info(layer: LayerSpec) -> kf.kdb.LayerInfo:
+    """Returns layer info from a layer spec."""
+    layer_index = get_layer(layer)
+    return kf.kcl.get_info(layer_index)  # type: ignore[no-any-return]
+
+
+def get_layer_views() -> LayerViews | str | PathType:
     return get_active_pdk().get_layer_views()
 
 
