@@ -19,7 +19,7 @@ def from_gdspaths(cells: "Sequence[ComponentOrPath]") -> Component:
         cells: List of gdspaths or Components.
 
     """
-    component = Component("merged")
+    component = Component(name="merged")
 
     for c in cells:
         if isinstance(c, str | pathlib.Path):
@@ -44,5 +44,5 @@ if __name__ == "__main__":
 
     # c = gdspaths([gf.components.straight(), gf.components.bend_circular()])
     # leave these two lines to end up tests showing the diff
-    c = from_gdspaths(diff_path.glob("*.gds"))
+    c = from_gdspaths(list(diff_path.glob("*.gds")))
     c.show()
