@@ -1,46 +1,50 @@
 from __future__ import annotations
 
-from typing import Any, Literal
+from typing import Any, Literal, cast
 
 import kfactory as kf
 import numpy as np
 from kfactory.routing.generic import ManhattanRoute
 
 import gdsfactory as gf
+from gdsfactory import typings
 from gdsfactory.component import Component
-from gdsfactory.port import Port, flipped
+from gdsfactory.port import flipped
 from gdsfactory.routing.route_single import route_single
+from gdsfactory.typings import CrossSectionSpec, Ports
 
 
-def sort_key_west_to_east(port: Port) -> float:
-    return port.dx
+def sort_key_west_to_east(port: typings.Port) -> float:
+    return port.x
 
 
-def sort_key_east_to_west(port: Port) -> float:
-    return -port.dx
+def sort_key_east_to_west(port: typings.Port) -> float:
+    return -port.x
 
 
-def sort_key_south_to_north(port: Port) -> float:
-    return port.dy
+def sort_key_south_to_north(port: typings.Port) -> float:
+    return port.y
 
 
-def sort_key_north_to_south(port: Port) -> float:
-    return -port.dy
+def sort_key_north_to_south(port: typings.Port) -> float:
+    return -port.y
 
 
 def route_ports_to_side(
     component: Component,
-    ports: list[kf.Port] | Component | list[gf.Port] | None = None,
+    cross_section: CrossSectionSpec,
+    ports: Ports | None = None,
     side: Literal["north", "east", "south", "west"] = "north",
-    x: float | None = None,
-    y: float | None = None,
+    x: float | None | Literal["east", "west"] = None,
+    y: float | None | Literal["north", "south"] = None,
     **kwargs: Any,
-) -> tuple[list[ManhattanRoute], list[kf.Port]]:
+) -> tuple[list[ManhattanRoute], list[kf.DPort]]:
     """Routes ports to a given side.
 
     Args:
         component: component to route.
-        ports: list/dict/Component/ComponentReference to route to a side.
+        cross_section: cross_section to use for routing.
+        ports: ports to route to a side.
         side: 'north', 'south', 'east' or 'west'.
         x: position to route ports for east/west. None, uses most east/west value.
         y: position to route ports for south/north. None, uses most north/south value.
@@ -61,18 +65,19 @@ def route_ports_to_side(
 
         import gdsfactory as gf
 
-        c = gf.Component('sample_route_sides')
+        c = gf.Component()
         dummy = gf.components.nxn(north=2, south=2, west=2, east=2)
         sides = ["north", "south", "east", "west"]
         d = 100
         positions = [(0, 0), (d, 0), (d, d), (0, d)]
 
         for pos, side in zip(positions, sides):
-            dummy_ref = dummy.ref(position=pos)
-            c.add(dummy_ref)
-            routes, ports = gf.routing.route_ports_to_side(dummy_ref, side, layer=(1, 0))
-            for route in routes:
-                c.add(route.references)
+            dummy_ref = c << dummy
+            dummy_ref.move(pos)
+            routes, ports = gf.routing.route_ports_to_side(
+                component=c, side=side, ports=dummy_ref.ports, cross_section="strip"
+            )
+
             for i, p in enumerate(ports):
                 c.add_port(name=f"{side[0]}{i}", port=p)
 
@@ -83,45 +88,39 @@ def route_ports_to_side(
         return [], []
 
     if side in {"north", "south"}:
-        func_route = route_ports_to_y
-        xy = y if y is not None else side
-    elif side in {"west", "east"}:
-        xy = x if x is not None else side
-        func_route = route_ports_to_x
+        y_value = y if y is not None else side
+        if isinstance(y_value, str):
+            y_value = cast(Literal["north", "south"], y_value)
+        side = cast(Literal["north", "south"], side)
+        return route_ports_to_y(
+            component=component,
+            ports=ports,
+            y=y_value,
+            side=side,
+            cross_section=cross_section,
+            **kwargs,
+        )
+    elif side in {"east", "west"}:
+        x_value = x if x is not None else side
+        if isinstance(x_value, str):
+            x_value = cast(Literal["east", "west"], x_value)
+        side = cast(Literal["west", "east"], side)
+        return route_ports_to_x(
+            component=component,
+            ports=ports,
+            x=x_value,
+            side=side,
+            cross_section=cross_section,
+            **kwargs,
+        )
     else:
-        raise ValueError(f"side = {side} not valid (north, south, west, east)")
-
-    ports = ports or component.ports
-    return func_route(component, ports, xy, side=side, **kwargs)
-
-
-def route_ports_to_north(
-    list_ports: list[Port], **kwargs: Any
-) -> tuple[list[ManhattanRoute], list[kf.Port]]:
-    return route_ports_to_side(list_ports, side="north", **kwargs)
-
-
-def route_ports_to_south(
-    list_ports: list[Port], **kwargs: Any
-) -> tuple[list[ManhattanRoute], list[kf.Port]]:
-    return route_ports_to_side(list_ports, side="south", **kwargs)
-
-
-def route_ports_to_west(
-    list_ports: list[Port], **kwargs: Any
-) -> tuple[list[ManhattanRoute], list[kf.Port]]:
-    return route_ports_to_side(list_ports, side="west", **kwargs)
-
-
-def route_ports_to_east(
-    list_ports: list[Port], **kwargs: Any
-) -> tuple[list[ManhattanRoute], list[kf.Port]]:
-    return route_ports_to_side(list_ports, side="east", **kwargs)
+        raise ValueError(f"side={side} must be 'north', 'south', 'east' or 'west'")
 
 
 def route_ports_to_x(
     component: Component,
-    list_ports: list[Port],
+    ports: Ports,
+    cross_section: CrossSectionSpec,
     x: float | Literal["east", "west"] = "east",
     separation: float = 10.0,
     radius: float = 10.0,
@@ -136,16 +135,17 @@ def route_ports_to_x(
     dy_start: float | None = None,
     side: Literal["east", "west"] = "east",
     **routing_func_args: Any,
-) -> tuple[list[ManhattanRoute], list[kf.Port]]:
+) -> tuple[list[ManhattanRoute], list[typings.Port]]:
     """Returns route to x.
 
     Args:
         component: component to route.
-        list_ports: reasonably well behaved list of ports.
+        ports: reasonably well behaved list of ports.
            ports facing north ports are norther than any other ports
            ports facing south ports are souther ...
            ports facing west ports are the wester ...
            ports facing east ports are the easter ...
+        cross_section: cross_section to use for routing.
         x: float or string.
            if float: x coordinate to which the ports will be routed
            if string: "east" -> route to east
@@ -176,18 +176,18 @@ def route_ports_to_x(
     4. north ports
 
     """
-    north_ports = [p for p in list_ports if p.orientation == 90]
-    south_ports = [p for p in list_ports if p.orientation == 270]
-    east_ports = [p for p in list_ports if p.orientation == 0]
-    west_ports = [p for p in list_ports if p.orientation == 180]
+    north_ports = [p for p in ports if p.orientation == 90]
+    south_ports = [p for p in ports if p.orientation == 270]
+    east_ports = [p for p in ports if p.orientation == 0]
+    west_ports = [p for p in ports if p.orientation == 180]
 
     epsilon = 1.0
     a = epsilon + max(radius, separation)
     bx = epsilon + max(radius, dx_start) if dx_start else a
     by = epsilon + max(radius, dy_start) if dy_start else a
 
-    xs = [p.dx for p in list_ports]
-    ys = [p.dy for p in list_ports]
+    xs = [p.x for p in ports]
+    ys = [p.y for p in ports]
 
     if y0_bottom is None:
         y0_bottom = min(ys) - by
@@ -202,13 +202,9 @@ def route_ports_to_x(
         extension_length = -extension_length
 
     if x == "east":
-        x = max(p.dx for p in list_ports) + bx
+        x = max(p.x for p in ports) + bx
     elif x == "west":
-        x = min(p.dx for p in list_ports) - bx
-    elif isinstance(x, float | int):
-        pass
-    else:
-        raise ValueError(f"x={x!r} should be a float or east or west")
+        x = min(p.x for p in ports) - bx
 
     if x < min(xs):
         sort_key_north = sort_key_west_to_east
@@ -237,14 +233,14 @@ def route_ports_to_x(
     backward_ports_thru_south.sort(key=sort_key_south_to_north)
     backward_ports_thru_north.sort(key=sort_key_north_to_south)
 
-    routes = []
-    ports = []
+    routes: list[ManhattanRoute] = []
+    new_ports: list[typings.Port] = []
 
     def add_port(
-        port: Port,
+        port: typings.Port,
         y: float,
         l_elements: list[ManhattanRoute],
-        l_ports: list[Port],
+        l_ports: list[typings.Port],
         start_straight_length: float = start_straight_length,
     ) -> None:
         if side == "west":
@@ -253,10 +249,13 @@ def route_ports_to_x(
         elif side == "east":
             angle = 180
 
+        else:
+            raise ValueError(f"{side=} should be either 'west' or 'east'")
+
         new_port = port.copy()
         new_port.orientation = angle
-        new_port.dx = x + extension_length
-        new_port.dy = y
+        new_port.x = x + extension_length
+        new_port.y = y
 
         new_port2 = new_port.copy()
         new_port2.trans *= gf.kdb.Trans.R180
@@ -268,22 +267,23 @@ def route_ports_to_x(
                 new_port,
                 start_straight_length=start_straight_length,
                 radius=radius,
+                cross_section=cross_section,
                 **routing_func_args,
             )
         ]
-        l_ports += [new_port2]
+        l_ports.append(new_port2)
 
     y_optical_bot = y0_bottom
     for p in south_ports:
-        add_port(p, y_optical_bot, routes, ports)
+        add_port(p, y_optical_bot, routes, new_ports)
         y_optical_bot -= separation
 
     for p in forward_ports:
-        add_port(p, p.dy, routes, ports)
+        add_port(p, p.y, routes, new_ports)
 
     y_optical_top = y0_top
     for p in north_ports:
-        add_port(p, y_optical_top, routes, ports)
+        add_port(p, y_optical_top, routes, new_ports)
         y_optical_top += separation
 
     start_straight_length_section = start_straight_length
@@ -291,11 +291,11 @@ def route_ports_to_x(
     min_x = min(xs)
 
     for p in backward_ports_thru_north:
-        # Extend ports if necessary
-        if angle == 0 and p.dx < max_x:
-            start_straight_length_section = max_x - p.dx
-        elif angle == 180 and p.dx > min_x:
-            start_straight_length_section = p.dx - min_x
+        # Extend new_ports if necessary
+        if angle == 0 and p.x < max_x:
+            start_straight_length_section = max_x - p.x
+        elif angle == 180 and p.x > min_x:
+            start_straight_length_section = p.x - min_x
         else:
             start_straight_length_section = 0
 
@@ -303,7 +303,7 @@ def route_ports_to_x(
             p,
             y_optical_top,
             routes,
-            ports,
+            new_ports,
             start_straight_length=start_straight_length + start_straight_length_section,
         )
         y_optical_top += separation
@@ -311,11 +311,11 @@ def route_ports_to_x(
 
     start_straight_length_section = start_straight_length
     for p in backward_ports_thru_south:
-        # Extend ports if necessary
-        if angle == 0 and p.dx < max_x:
-            start_straight_length_section = max_x - p.dx
-        elif angle == 180 and p.dx > min_x:
-            start_straight_length_section = p.dx - min_x
+        # Extend new_ports if necessary
+        if angle == 0 and p.x < max_x:
+            start_straight_length_section = max_x - p.x
+        elif angle == 180 and p.x > min_x:
+            start_straight_length_section = p.x - min_x
         else:
             start_straight_length_section = 0
 
@@ -323,18 +323,19 @@ def route_ports_to_x(
             p,
             y_optical_bot,
             routes,
-            ports,
+            new_ports,
             start_straight_length=start_straight_length + start_straight_length_section,
         )
         y_optical_bot -= separation
         start_straight_length += separation
 
-    return routes, ports
+    return routes, new_ports
 
 
 def route_ports_to_y(
     component: Component,
-    list_ports: list[Port],
+    ports: Ports,
+    cross_section: CrossSectionSpec,
     y: float | Literal["north", "south"] = "north",
     separation: float = 10.0,
     radius: float = 10.0,
@@ -348,17 +349,18 @@ def route_ports_to_y(
     dx_start: float | None = None,
     dy_start: float | None = None,
     side: Literal["north", "south"] = "north",
-    **routing_func_args: dict[Any, Any],
-) -> tuple[list[ManhattanRoute], list[kf.Port]]:
+    **routing_func_args: Any,
+) -> tuple[list[ManhattanRoute], list[typings.Port]]:
     """Route ports to y.
 
     Args:
         component: component to route.
-        list_ports: reasonably well behaved list of ports.
+        ports: reasonably well behaved list of ports.
            ports facing north ports are norther than any other ports
            ports facing south ports are souther ...
            ports facing west ports are the wester ...
            ports facing east ports are the easter ...
+        cross_section: cross_section to use for routing.
         y: float or string.
                if float: y coordinate to which the ports will be routed
                if string: "north" -> route to north
@@ -396,16 +398,14 @@ def route_ports_to_y(
 
     da = 45
     north_ports = [
-        p for p in list_ports if p.orientation > 90 - da and p.orientation < 90 + da
+        p for p in ports if p.orientation > 90 - da and p.orientation < 90 + da
     ]
     south_ports = [
-        p for p in list_ports if p.orientation > 270 - da and p.orientation < 270 + da
-    ]
-    east_ports = [
-        p for p in list_ports if p.orientation < da or p.orientation > 360 - da
+        p for p in ports if p.orientation > 270 - da and p.orientation < 270 + da
     ]
+    east_ports = [p for p in ports if p.orientation < da or p.orientation > 360 - da]
     west_ports = [
-        p for p in list_ports if p.orientation < 180 + da and p.orientation > 180 - da
+        p for p in ports if p.orientation < 180 + da and p.orientation > 180 - da
     ]
 
     epsilon = 1.0
@@ -413,8 +413,8 @@ def route_ports_to_y(
     bx = epsilon + max(radius, dx_start) if dx_start else a
     by = epsilon + max(radius, dy_start) if dy_start else a
 
-    xs = [p.dx for p in list_ports]
-    ys = [p.dy for p in list_ports]
+    xs = [p.x for p in ports]
+    ys = [p.y for p in ports]
 
     if x0_left is None:
         x0_left = min(xs) - bx
@@ -425,30 +425,24 @@ def route_ports_to_y(
     x0_right += extend_right
 
     if y == "north":
-        y = (
-            max(
-                p.dy + a * np.abs(np.cos(p.orientation * np.pi / 180))
-                for p in list_ports
-            )
+        y_float = (
+            max(p.y + a * np.abs(np.cos(p.orientation * np.pi / 180)) for p in ports)
             + by
         )
     elif y == "south":
-        y = (
-            min(
-                p.dy - a * np.abs(np.cos(p.orientation * np.pi / 180))
-                for p in list_ports
-            )
+        y_float = (
+            min(p.y - a * np.abs(np.cos(p.orientation * np.pi / 180)) for p in ports)
             - by
         )
     elif isinstance(y, float | int):
-        pass
-    if y <= min(ys):
+        y_float = y
+    if y_float <= min(ys):
         sort_key_east = sort_key_south_to_north
         sort_key_west = sort_key_south_to_north
         forward_ports = south_ports
         backward_ports = north_ports
 
-    elif y >= max(ys):
+    elif y_float >= max(ys):
         sort_key_west = sort_key_north_to_south
         sort_key_east = sort_key_north_to_south
         forward_ports = north_ports
@@ -469,13 +463,13 @@ def route_ports_to_y(
     backward_ports_thru_east.sort(key=sort_key_east_to_west)
 
     routes: list[ManhattanRoute] = []
-    ports: list[Port] = []
+    new_ports: list[typings.Port] = []
 
     def add_port(
-        port: Port,
+        port: typings.Port,
         x: float,
         l_elements: list[ManhattanRoute],
-        l_ports: list[Port],
+        l_ports: list[typings.Port],
         start_straight_length: float = start_straight_length,
     ) -> None:
         if side == "south":
@@ -486,7 +480,7 @@ def route_ports_to_y(
 
         new_port = port.copy()
         new_port.orientation = angle
-        new_port.dcenter = (x, y + extension_length)
+        new_port.center = (x, y_float + extension_length)
 
         if np.sum(np.abs((np.array(new_port.center) - port.center) ** 2)) < 1:
             l_ports += [flipped(new_port)]
@@ -500,6 +494,7 @@ def route_ports_to_y(
                     new_port,
                     start_straight_length=start_straight_length,
                     radius=radius,
+                    cross_section=cross_section,
                     **routing_func_args,
                 )
             ]
@@ -512,15 +507,15 @@ def route_ports_to_y(
 
     x_optical_left = x0_left
     for p in west_ports:
-        add_port(p, x_optical_left, routes, ports)
+        add_port(p, x_optical_left, routes, new_ports)
         x_optical_left -= separation
 
     for p in forward_ports:
-        add_port(p, p.dx, routes, ports)
+        add_port(p, p.x, routes, new_ports)
 
     x_optical_right = x0_right
     for p in east_ports:
-        add_port(p, x_optical_right, routes, ports)
+        add_port(p, x_optical_right, routes, new_ports)
         x_optical_right += separation
 
     start_straight_length_section = start_straight_length
@@ -529,7 +524,7 @@ def route_ports_to_y(
             p,
             x_optical_right,
             routes,
-            ports,
+            new_ports,
             start_straight_length=start_straight_length_section,
         )
         x_optical_right += separation
@@ -541,30 +536,41 @@ def route_ports_to_y(
             p,
             x_optical_left,
             routes,
-            ports,
+            new_ports,
             start_straight_length=start_straight_length_section,
         )
         x_optical_left -= separation
         start_straight_length_section += separation
 
-    return routes, ports
+    return routes, new_ports
 
 
 if __name__ == "__main__":
-    c = Component("sample_route_sides")
+    c = Component()
     cross_section = "strip"
-    dummy = gf.components.nxn(
-        north=2, south=2, west=2, east=2, cross_section=cross_section
-    )
+    dummy = gf.c.nxn(north=2, south=2, west=2, east=2, cross_section=cross_section)
     dummy_ref = c << dummy
-    routes = route_ports_to_side(
+    # routes, _ = route_ports_to_side(
+    #     c,
+    #     ports=dummy_ref.ports,
+    #     side="south",
+    #     cross_section=cross_section,
+    #     y=-91,
+    #     x=-100,
+    # )
+    # routes, _ = gf.routing.route_ports_to_side(
+    #     c,
+    #     ports=dummy_ref.ports,
+    #     cross_section=cross_section,
+    #     x=50,
+    #     side="east",
+    # )
+    routes, _ = route_ports_to_side(
         c,
-        dummy_ref.ports,
-        "south",
+        ports=dummy_ref.ports,
         cross_section=cross_section,
-        y=-91,
-        x=-100,
-        # radius=5
+        y=50,
+        side="north",
     )
     # sides = ["north", "south", "east", "west"]
     # d = 100
@@ -572,7 +578,7 @@ if __name__ == "__main__":
 
     # for pos, side in zip(positions, sides):
     #     dummy_ref = c << dummy
-    #     dummy_ref.dcenter = pos
+    #     dummy_ref.center = pos
     #     routes = route_ports_to_side(c, dummy_ref.ports, side, layer=(1, 0))
 
     c.show()
