@@ -3,13 +3,15 @@
 from __future__ import annotations
 
 import warnings
+from collections.abc import Sequence
 from functools import partial
+from typing import Any, TypeAlias, TypeVar, cast, overload
 
 import kfactory as kf
 import numpy as np
 import numpy.typing as npt
 
-Value = float | tuple[float, ...] | npt.NDArray[np.float64]
+Value: TypeAlias = float | Sequence[float] | npt.NDArray[np.floating[Any]]
 
 
 def is_on_grid(
@@ -24,7 +26,7 @@ def is_on_grid(
 
 def warn_if_not_on_grid(x: Value) -> None:
     if not is_on_grid(x):
-        warnings.warn(f"{x} is not on grid", stacklevel=2)
+        warnings.warn(f"{x} is not on grid", stacklevel=3)
 
 
 def assert_on_grid(
@@ -47,11 +49,32 @@ def assert_on_2x_grid(x: float) -> None:
         raise ValueError(f"{x} needs to be on 2x grid and should be {x_grid}")
 
 
+_T = TypeVar("_T", bound=npt.NDArray[np.floating[Any]])
+
+
+@overload
 def snap_to_grid(
-    x: Value,
+    x: _T,
     nm: int | None = None,
     grid_factor: int = 1,
-) -> npt.NDArray[np.float64]:
+) -> _T: ...
+@overload
+def snap_to_grid(
+    x: Sequence[float],
+    nm: int | None = None,
+    grid_factor: int = 1,
+) -> npt.NDArray[np.floating[Any]]: ...
+@overload
+def snap_to_grid(
+    x: float,
+    nm: int | None = None,
+    grid_factor: int = 1,
+) -> float: ...
+def snap_to_grid(
+    x: float | Sequence[float] | _T,
+    nm: int | None = None,
+    grid_factor: int = 1,
+) -> _T | float:
     """Snap x to grid.
 
     Args:
@@ -61,14 +84,31 @@ def snap_to_grid(
     """
     grid_size = kf.kcl.dbu
     nm = nm or round(grid_size * 1000 * grid_factor)
-    return nm * np.round(np.asarray(x, dtype=float) * 1e3 / nm) / 1e3
+    res = nm * np.round(np.asarray(x, dtype=float) * 1e3 / nm) / 1e3
+    if isinstance(res, np.floating):
+        return float(res)
+    return cast(_T | float, res)
 
 
-snap_to_grid2x = partial(snap_to_grid, grid_factor=2)
+@overload
+def snap_to_grid2x(
+    x: Sequence[float] | npt.NDArray[np.floating[Any]],
+    nm: int | None = None,
+) -> npt.NDArray[np.floating[Any]]: ...
+@overload
+def snap_to_grid2x(
+    x: float,
+    nm: int | None = None,
+) -> float: ...
+def snap_to_grid2x(
+    x: Value,
+    nm: int | None = None,
+) -> npt.NDArray[np.floating[Any]] | float:
+    return snap_to_grid(x, nm, grid_factor=2)
 
 
 if __name__ == "__main__":
-    print(assert_on_grid(1.1e-3))
+    assert_on_grid(1.1e-3)
     # print(snap_to_grid(1.1e-3))
     # print(snap_to_2nm_grid(1.1e-3))
     # print(snap_to_2nm_grid(3.1e-3))
