@@ -3,7 +3,7 @@ import xml.etree.ElementTree as ET
 from xml.dom.minidom import Node
 
 
-def _strip_xml(node: Node) -> None:
+def strip_xml(node: Node) -> None:
     """Strip XML of excess whitespace.
 
     Source: https://stackoverflow.com/a/16919069
@@ -13,14 +13,14 @@ def _strip_xml(node: Node) -> None:
             if x.nodeValue:
                 x.nodeValue = x.nodeValue.strip()
         elif x.nodeType == Node.ELEMENT_NODE:
-            _strip_xml(x)
+            strip_xml(x)
 
 
 def make_pretty_xml(root: ET.Element) -> bytes:
     """Make XML pretty."""
     xml_doc = xml.dom.minidom.parseString(ET.tostring(root))
 
-    _strip_xml(xml_doc)
+    strip_xml(xml_doc)
     xml_doc.normalize()
 
     return xml_doc.toprettyxml(indent=" ", newl="\n", encoding="utf-8")
